.PU
.TH CRYSTAL 1 
.SH NAME
Crystal - A program to make ball-and-stick, or polyhedral
crystal structure drawings

.SH SYNOPSIS
.B crystal
.RB [ options ]
[
.I datafile
]
.SH DESCRIPTION

This program reads a basic description of the crystal structure, which includes unit-cell
parameters, space group and atomic coordinates, and outputs a geometry object that
contains polyhedra, spheres, bonds, and the unit-cell boundary. 

This program exists in three versions, which are created from a common
source through compile-time defines: 
.br
1. an 
.B AVS 
module originally written by  Dr. Larry Finger 
of the Geophysical Laboratory, Carnegie Institution of Washington
.br
and 
.br
2. a modified version by Dr. Martin Kroeker, Organic Chemistry, Technical University
of Darmstadt, Germany, which adds some view options and contains the output routines 
to generate a scene description file in VRML format and optionally also for the popular 
.B POV 
ray-tracer program. This scene file can be used as is, but it can also be 
edited to make use of the more sophisticated (or un-scientific) features of 
.B POV 
like transparency, backgrounds or light effects. The 
.B POV 
program is available from
.B ftp.povray.org.  


Source code for crystal is available at
.B ftp://cryst.ciw.edu/anonymous/avs.  
and
.B ftp://tutor.oc.chemie.th-darmstadt.de/pub/crystal

The necessary files are crystal.c, symmtry.c, and makefile.  

Postscript and Word 6.0 versions of this writeup may also be
available as 
.B crystal.ps 
and 
.B crystal.doc
, respectively.  

To compile the POV or VRML version, include
a 
.B -D_POV_ 
or
.B -DVRML
switch on the compiler call, respectively. 

.SH COMMANDS

Both versions can read the same input file; however, the 
.B AVS 
version will ignore any
color information that is presented - colors are set using the Geometry Viewer in 
.B AVS. 
In addition, the 
.B AVS 
version will ignore the  
.B box 
,
.B edges 
,
.B plane
and  
.B view 
commands.  Each line of the input file is preceded by a character sequence 
that describes the type of information, as follows: 


.TP
.B titl

General description of the Structure


.TP
.B cell 

Unit-cell lengths and angles.  If no angles are listed, they are assumed 
to be the fixed values for the symmetry class.


.TP
.B spgp 
or  
.B sgrp 

Space Group name consisting of the Bravais lattice symbol followed by a space,
the elements parallel to the first axis followed by a space, etc.  Examples are I 41/a
m d, P 21/n, I a 3 d, P b n m, etc. The generators will always select the origin 
choice with a center of symmetry at the origin.  Furthermore, all monoclinic cells
will have the unique axis parallel to the b axis.


.TP
.B sphere 
name radius color

where 'name' is a one- or two-character symbol of the atom type, 'radius' is the 
radius of the sphere in Angstrom, and 'color' is one of the color names from POV's
.B colors.inc 
file.

.TP
.B bond 
name1 name2 radius min_length max_length color

where 'name1' and 'name2' indicate the types of atoms to be connected by a bond,
'radius' is the radius of the resulting cylinder, and the minimum and maximum
lengths are given in Angstrom.

.TP
.B polysz  
name length color

defines a polyhedron, where 'name' is the name of an atom at the center of a
polyhedron and 'length' is the maximum length of distances to atoms that are to be
considered as the vertices of the polyhedron.  No atoms that are mentioned in
.B sphere 
or 
.B polysz 
commands will be considered as the vertices of a polyhedron.
(but note that spheres on the vertices of polyhedra, as sometimes used to
distinguish OH from O in phosphates, can be created by duplicating a position and
using one of them as center of a sphere)

.TP
.B plane  
name length color

defines a polygon that encompasses the planar coordination environment of 
atom 'name'.

.TP
.B atom  
name number x y z

defines the atoms.  The 1- or 2-character name will be used on the commands that
describe the objects to be created, the number is to keep track of the atom, 
and 'x', 'y', 'z' are the fractional coordinates in the unit cell.

.TP
.B box 
radius  color
.br
(POV and VRML version only)

defines the radius and color of the cylinders that form the unit cell boundary.

.TP
.B edges 
radius  color    
.br
(POV and VRML version only)

defines the thickness and color of cylinders along the edges of polyhedra that may
be used to emphasize the faces.

.TP
.B view 
xrot   yrot   zrot 
.br
(POV version only)

where 'xrot', 'yrot' and 'zrot' are view rotation angles in Cartesian space

.TP
.B end 

The last line of a file.

.SH EXAMPLE

Sample input file: set the origin at 0,0,0

title Buckyball 
.br
cell 14.16 14.16 14.16 
.br
spgp F m 3 
.br
sphere c 0.4 Green 
.br
bond c c 0.1 1.2 1.5 
.br
atom c 1 0.04908 0.00000 0.24510 
.br
atom c 2 0.10028 0.08284 0.21346 
.br
atom c 3 0.18313 0.05120 0.16226 
.br
end

.SH COMMAND LINE OPTIONS

In the 
.B AVS 
version, the view limits are set by the use of slider widgets; whereas similar 
information is input via command line switches for the standalone 
.B POV 
and 
.B VRML
versions as follows:

.TP
.B -b 
xlim ylim zlim
 
defines X-, Y- and Z-limits of the view box in angstroms 
(defaults to -10..10 Angstroms around center)

.TP
.B -p 
xmin xmax ymin ymax zmin zmax

defines a-,b-,c- plotting range in fractions of the axes, similar to the 
.B Pluto
(Motherwell & Clegg 1978)
.B PACK RANGE 
command (this is especially useful for hexagonal cells, where the orthorhombic
view box does not always give satisfactory results)

.TP
.B -h, -?

displays usage information

.TP
.B -n
 
suppresses plotting of unit cell 'box'

.TP
.B -o 
xcenter ycenter zcenter

defines center of view box in crystal coordinates 
(defaults to 0.5 0.5 0.5)

.TP
.B -v 
xangle yangle zangle

defines view rotation angles around the axes of the Cartesian view coordinate
system (equivalent to the 
.B view 
keyword)

.SH SEE ALSO
The 
.B AVS
and
.B POV
User Manuals

.SH AUTHORS
Dr. Larry Finger 
.B (finger@gl.ciw.edu) 
.br
Geophysical Laboratory, 
.br
Carnegie Institution of Washington, 
.br
5251 Broad Branch Road, N.W., Washington, DC 20015-1305, 


POV- and VRML-related additions by 
.br
Dr. Martin Kroeker 
.B (martin@oc2.oc.chemie.th-darmstadt.de), 
.br
Institut fuer Organische Chemie, 
.br
Technische Hochschule Darmstadt, 
.br
Petersenstrasse 22
.br
D-64287 Darmstadt, Germany

